@@ -2,7 +2,6 @@
 
 from biopsykit.carwatch_logs.log_data import LogData, LogDataInfo, subject_conditions, smartphone_models
 from biopsykit.carwatch_logs.log_statistics import LogStatistics
-
-import biopsykit.carwatch_logs.widgets as widgets
+from biopsykit.carwatch_logs import widgets
 
 __all__ = ["LogData", "LogDataInfo", "LogStatistics", "smartphone_models", "subject_conditions", "widgets"]
