@@ -7,7 +7,10 @@ import json
 import pandas as pd
 import matplotlib.pyplot as plt
 
+from tqdm.auto import tqdm
+
 import biopsykit.protocols.plotting as plot
+from biopsykit.io import write_pandas_dict_excel
 from biopsykit.protocols._utils import _check_sample_times_match, _get_sample_times
 from biopsykit.signals.ecg import EcgProcessor
 from biopsykit.utils._datatype_validation_helper import _assert_is_dtype, _assert_file_extension
@@ -27,12 +30,13 @@ from biopsykit.utils.data_processing import (
 )
 from biopsykit.utils.datatype_helper import (
     HeartRateSubjectDataDict,
-    is_study_data_dict,
     SalivaRawDataFrame,
     is_saliva_raw_dataframe,
     SubjectDataDict,
     SalivaFeatureDataFrame,
     is_saliva_mean_se_dataframe,
+    is_subject_data_dict,
+    is_hr_subject_data_dict,
 )
 from biopsykit.utils.exceptions import ValidationError
 
@@ -315,7 +319,7 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
         file_path = Path(file_path)
         _assert_file_extension(file_path, ".json")
 
-        with open(file_path, "w+", encoding="utf-8") as fp:
+        with open(file_path, encoding="utf-8") as fp:
             json_dict = json.load(fp)
             return cls(**json_dict)
 
@@ -407,11 +411,12 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
             Default: ``None``
 
         """
-        is_study_data_dict(hr_data)
+        is_hr_subject_data_dict(hr_data)
         if study_part is None:
             study_part = "Study"
         self.hr_data[study_part] = hr_data
         if rpeak_data is not None:
+            is_subject_data_dict(rpeak_data)
             self.rpeak_data[study_part] = rpeak_data
 
     def compute_hr_results(  # pylint:disable=too-many-branches
@@ -598,7 +603,7 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
         self, rpeak_dict: Dict[str, Any], hrv_params: Dict[str, Any], dict_levels: Sequence[str]
     ) -> pd.DataFrame:
         result_dict = {}
-        for key, value in rpeak_dict.items():
+        for key, value in tqdm(list(rpeak_dict.items()), desc=dict_levels[0]):
             _assert_is_dtype(value, (dict, pd.DataFrame))
             if isinstance(value, dict):
                 # nested dictionary
@@ -720,6 +725,7 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
             dataframe with computed heart rate processing ensemble
 
         """
+        _assert_is_dtype(results, pd.DataFrame)
         self.hr_results[result_id] = results
 
     def get_hr_results(self, result_id: str) -> pd.DataFrame:
@@ -767,6 +773,19 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
         """
         self._export_results(base_path, prefix, self.hr_results)
 
+    def export_hr_ensemble(self, base_path: path_t, prefix: Optional[str] = None):
+        """Export all heart rate ensemble data to Excel files.
+
+        Parameters
+        ----------
+        base_path : :class:`~pathlib.Path` or str
+            folder path to export all heart rate ensemble files to
+        prefix : str, optional
+            prefix to add to file name or ``None`` to use ``name`` attribute (in lowercase) as prefix
+
+        """
+        self._export_ensemble(base_path, prefix, self.hr_ensemble)
+
     def export_hrv_results(self, base_path: path_t, prefix: Optional[str] = None):
         """Export all heart rate variability results to csv files.
 
@@ -791,6 +810,17 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
             file_name = "{}_{}.csv".format(prefix, key)
             data.to_csv(base_path.joinpath(file_name))
 
+    def _export_ensemble(self, base_path: path_t, prefix: str, result_dict: Dict[str, Dict[str, pd.DataFrame]]):
+        # ensure pathlib
+        base_path = Path(base_path)
+        if not base_path.is_dir():
+            raise ValueError("'base_path' must be a directory!")
+        if prefix is None:
+            prefix = self.name.lower().replace(" ", "_")
+        for key, data in result_dict.items():
+            file_name = "{}_{}.xlsx".format(prefix, key)
+            write_pandas_dict_excel(data, base_path.joinpath(file_name))
+
     def get_hrv_results(self, result_id: str) -> pd.DataFrame:
         """Return heart rate variability processing ensemble.
 
@@ -822,6 +852,7 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
             ensemble data as ``MergedStudyDataDict``
 
         """
+        _assert_is_dtype(ensemble, dict)
         self.hr_ensemble[ensemble_id] = ensemble
 
     def get_hr_ensemble(self, ensemble_id: str):
@@ -1017,7 +1048,7 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
     def hr_ensemble_plot(
         self, ensemble_id: str, subphases: Optional[Dict[str, Dict[str, int]]] = None, **kwargs
     ) -> Tuple[plt.Figure, plt.Axes]:
-        """Draw heart rate ensemble plot.
+        r"""Draw heart rate ensemble plot.
 
         Parameters
         ----------
@@ -1029,8 +1060,37 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
             dictionary with phases (keys) and subphases (values - dict with subphase names and subphase durations) or
             ``None`` if no subphases are present. Default: ``None``
         **kwargs : dict, optional
-            optional arguments for plot configuration to be passed to
-            :func:`~biopsykit.protocols.plotting.hr_ensemble_plot`
+            additional parameters to be passed to :func:`~biopsykit.protocols.plotting.hr_ensemble_plot` for
+            plot configuration, such as:
+
+            * ``ax``: pre-existing axes for the plot. Otherwise, a new figure and axes object is created and returned.
+            * ``palette``: color palette to plot data from different phases. If ``palette`` is a str then it is
+              assumed to be the name of a BioPsyKit palette (:const:`biopsykit.colors.FAU_COLORS`).
+            * ``figsize``: tuple specifying figure dimensions
+            * ``ensemble_alpha``: transparency value for ensemble plot errorband (around mean). Default: 0.3
+            * ``background_alpha``: transparency value for background spans (if subphases are present). Default: 0.2
+            * ``linestyle``: list of line styles for ensemble plots. Must match the number of phases to plot
+            * ``phase_text``: string pattern to customize phase name shown in legend with placeholder for subphase name.
+              Default: "{}"
+
+            To style axes:
+
+            * ``xlabel``: label of x axis. Default: ":math:`Time [s]`"
+            * ``xaxis_minor_tick_locator``: locator object to style x axis minor ticks. Default: 60 sec
+            * ``ylabel``: label of y axis. Default: ":math:`\Delta HR [\%]`"
+            * ``ylims``: y axis limits. Default: ``None`` to automatically infer limits
+
+            To style the annotations at the end of each phase:
+
+            * ``end_phase_text``: string pattern to customize text at the end of phase with placeholder for phase name.
+              Default: "{}"
+            * ``end_phase_line_color``: line color of vertical lines used to indicate end of phase. Default: "#e0e0e0"
+            * ``end_phase_line_width``: line width of vertical lines used  to indicate end of phase. Default: 2.0
+
+            To style legend:
+
+            * ``legend_loc``: location of legend. Default: "lower right"
+            * ``legend_bbox_to_anchor``: box that is used to position the legend in conjunction with ``legend_loc``
 
 
         Returns
@@ -1073,12 +1133,17 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
         result_id : str
             identifier of the heart rate result data to be plotted
         **kwargs
-            additional  parameters to be passed to the plot, such as:
+            additional parameters to be passed to :func:`~biopsykit.protocols.plotting.hr_mean_plot` for
+            plot configuration, such as:
 
             * ``ax``: pre-existing axes for the plot. Otherwise, a new figure and axes object is created
               and returned.
-            * ``colormap``: colormap to plot data from different phases
             * ``figsize``: tuple specifying figure dimensions
+            * ``palette``: color palette to plot data from different conditions. If ``palette`` is a str then it is
+              assumed to be the name of a BioPsyKit palette (:const:`biopsykit.colors.FAU_COLORS`).
+            * ``is_relative``: boolean indicating whether heart rate data is relative (in % relative to baseline)
+              or absolute (in bpm). Default: ``False``
+            * ``order``: list specifying the order of categorical values (i.e., conditions) along the x axis.
             * ``x_offset``: offset value to move different groups along the x axis for better visualization.
               Default: 0.05
             * ``xlabel``: label of x axis. Default: "Subphases" (if subphases are present)
@@ -1105,8 +1170,10 @@ class BaseProtocol:  # pylint:disable=too-many-public-methods
 
         See Also
         --------
+        :func:`~biopsykit.protocols.plotting.hr_mean_plot`
+            Plot heart rate data as lineplot with mean and standard error
         :func:`~biopsykit.plotting.lineplot`
-            Plot data as lineplot with mean and standard error
+            Plot generic data as lineplot with mean and standard error
 
         """
         data = mean_se_per_phase(self.hr_results[result_id])
