@@ -3,6 +3,8 @@ from typing import Union, Dict, Optional, Sequence, Tuple, Any, Iterable
 
 import re
 
+from typing_extensions import get_args
+
 import pandas as pd
 import numpy as np
 import seaborn as sns
@@ -15,6 +17,7 @@ from matplotlib.legend_handler import HandlerTuple
 from biopsykit.colors import colors
 from biopsykit.plotting import lineplot, multi_feature_boxplot, feature_boxplot
 from biopsykit.protocols._utils import _get_sample_times
+from biopsykit.saliva.utils import _remove_s0
 from biopsykit.utils.exceptions import ValidationError
 from biopsykit.utils.data_processing import get_subphase_durations
 from biopsykit.utils.datatype_helper import (
@@ -30,11 +33,11 @@ from biopsykit.utils.datatype_helper import (
 )
 
 _hr_ensemble_plot_params = {
-    "colormap": colors.fau_palette_blue("ensemble"),
-    "linestyle": ["-", "--", ":", "-."],
-    "ensemble_alpha": 0.4,
-    "background_color": ["#e0e0e0", "#9e9e9e", "#808080", "#6b6b6b"],
-    "background_alpha": 0.5,
+    "linestyle": ["solid", "dashed", "dotted", "dashdot"],
+    "ensemble_alpha": 0.3,
+    "background_base_color": "#e0e0e0",
+    "background_color": None,
+    "background_alpha": 0.2,
     "xlabel": r"Time [s]",
     "xaxis_minor_tick_locator": mticks.MultipleLocator(60),
     "ylabel": r"$\Delta$HR [%]",
@@ -48,11 +51,11 @@ _hr_ensemble_plot_params = {
 }
 
 _hr_mean_plot_params = {
-    "colormap": colors.fau_palette_blue("line_2"),
-    "linestyle": ["-", "--"],
-    "marker": ["o", "P"],
-    "background_color": ["#e0e0e0", "#bdbdbd", "#9e9e9e"],
-    "background_alpha": 0.5,
+    "linestyle": ["solid", "dashed", "dotted", "dashdot"],
+    "marker": ["o", "P", "*", "X"],
+    "background_base_color": "#e0e0e0",
+    "background_color": None,
+    "background_alpha": 0.2,
     "x_offset": 0.1,
     "ylabel": r"Heart Rate [bpm]",
     "phase_text": "{}",
@@ -64,6 +67,7 @@ _saliva_feature_params: Dict[str, Dict[str, Any]] = {
             "auc": r"Cortisol AUC $\left[\frac{nmol \cdot min}{l} \right]$",
             "auc_g": r"Cortisol AUC $\left[\frac{nmol \cdot min}{l} \right]$",
             "auc_i": r"Cortisol AUC $\left[\frac{nmol \cdot min}{l} \right]$",
+            "auc_i_post": r"Cortisol AUC $\left[\frac{nmol \cdot min}{l} \right]$",
             "slope": r"Cortisol Change $\left[\frac{nmol}{l \cdot min} \right]$",
             "max": r"Cortisol $\left[\frac{nmol}{l} \right]$",
             "argmax": r"Cortisol $\left[\frac{nmol}{l} \right]$",
@@ -76,6 +80,7 @@ _saliva_feature_params: Dict[str, Dict[str, Any]] = {
         "amylase": {
             "auc_g": r"Amylase AUC $\left[\frac{U \cdot min}{l} \right]$",
             "auc_i": r"Amylase AUC $\left[\frac{U \cdot min}{l} \right]$",
+            "auc_i_post": r"Amylase AUC $\left[\frac{U \cdot min}{l} \right]$",
             "slope": r"Amylase Change $\left[\frac{U}{l \cdot min} \right]$",
             "max": r"Amylase $\left[\frac{U}{l} \right]$",
             "max_inc": r"Amylase $\left[\frac{U}{l} \right]$",
@@ -89,6 +94,7 @@ _saliva_feature_params: Dict[str, Dict[str, Any]] = {
         "auc": r"$AUC_{$}$",
         "auc_g": r"$AUC_G$",
         "auc_i": r"$AUC_I$",
+        "auc_i_post": r"$AUC_{I}^{Post}$",
         "slope": r"$a_{§}$",
         "max_inc": r"$\Delta c_{max}$",
         "cmax": r"$c_{max}$",
@@ -101,10 +107,11 @@ _saliva_feature_params: Dict[str, Dict[str, Any]] = {
 }
 
 _saliva_plot_params: Dict = {
-    "colormap": colors.fau_palette_blue("line_2"),
+    "palette": None,
     "linestyle": ["-", "--"],
     "marker": ["o", "P"],
     "test_title": "",
+    "test_fontsize": "medium",
     "test_color": "#9e9e9e",
     "test_alpha": 0.5,
     "multi_x_offset": 0.01,
@@ -118,6 +125,15 @@ _saliva_plot_params: Dict = {
 }
 
 
+def _get_palette(palette: Union[str, Sequence[Tuple[int]]], num_colors: int):
+    if palette is None:
+        palette = colors.fau_palette_blue(num_colors)
+    elif isinstance(palette, str) and palette in get_args(colors.FAU_COLORS):
+        palette = colors.fau_palette_by_name(palette)(num_colors)
+
+    return palette
+
+
 def hr_ensemble_plot(
     data: MergedStudyDataDict,
     subphases: Optional[Dict[str, Dict[str, int]]] = None,
@@ -147,8 +163,9 @@ def hr_ensemble_plot(
         To style general plot appearance:
 
         * ``ax``: pre-existing axes for the plot. Otherwise, a new figure and axes object is created and returned.
-        * ``colormap``: colormap to plot data from different phases
-        * ``ensemble_alpha``: transparency value for ensemble plot errorband (around mean). Default: 0.4
+        * ``palette``: color palette to plot data from different phases
+        * ``ensemble_alpha``: transparency value for ensemble plot errorband (around mean). Default: 0.3
+        * ``background_alpha``: transparency value for background spans (if subphases are present). Default: 0.2
         * ``linestyle``: list of line styles for ensemble plots. Must match the number of phases to plot
         * ``phase_text``: string pattern to customize phase name shown in legend with placeholder for subphase name.
           Default: "{}"
@@ -203,13 +220,14 @@ def hr_ensemble_plot(
     """
     ax: plt.Axes = kwargs.pop("ax", None)
     if ax is None:
-        figsize = kwargs.get("figsize", _hr_ensemble_plot_params.get("figsize"))
-        fig, ax = plt.subplots(figsize=figsize)
+        fig, ax = plt.subplots(figsize=kwargs.get("figsize"))
     else:
         fig = ax.get_figure()
 
-    colormap = kwargs.get("colormap", _hr_ensemble_plot_params.get("colormap"))
-    sns.set_palette(colormap)
+    palette = kwargs.get("palette")
+    palette = _get_palette(palette, len(data))
+    sns.set_palette(palette)
+
     linestyle = kwargs.get("linestyle", _hr_ensemble_plot_params.get("linestyle"))
 
     xlabel = kwargs.get("xlabel", _hr_ensemble_plot_params.get("xlabel"))
@@ -220,7 +238,6 @@ def hr_ensemble_plot(
     )
 
     ensemble_alpha = kwargs.get("ensemble_alpha", _hr_ensemble_plot_params.get("ensemble_alpha"))
-
     phase_text = kwargs.get("phase_text", _hr_ensemble_plot_params.get("phase_text"))
 
     legend_loc = kwargs.get("legend_loc", _hr_ensemble_plot_params.get("legend_loc"))
@@ -315,12 +332,6 @@ def _hr_ensemble_plot_subphase_vspans(
         dictionary with phases (keys) and subphases (values - dict with subphase names and subphase durations)
 
     """
-    num_phases = len(data.keys())
-
-    bg_colors = kwargs.get("background_color", _hr_ensemble_plot_params.get("background_color"))
-    bg_alphas = kwargs.get("background_alpha", _hr_ensemble_plot_params.get("background_alpha"))
-    bg_alphas = [bg_alphas] * num_phases
-
     subphase_times = [get_subphase_durations(df, subphases[phase]) for phase, df in data.items()]
     subphase_times = np.array(subphase_times)
     subphase_times = np.max(subphase_times, axis=0)
@@ -331,6 +342,13 @@ def _hr_ensemble_plot_subphase_vspans(
         raise ValueError("Subphases must be the same for all phases!")
     subphase_names = subphase_names[0]
 
+    bg_colors = kwargs.get("background_color", _hr_ensemble_plot_params.get("background_color"))
+    if bg_colors is None:
+        bg_color_base = kwargs.get("background_base_color", _hr_ensemble_plot_params.get("background_base_color"))
+        bg_colors = list(sns.dark_palette(bg_color_base, n_colors=len(subphase_names), reverse=True))
+    bg_alphas = kwargs.get("background_alpha", _hr_ensemble_plot_params.get("background_alpha"))
+    bg_alphas = [bg_alphas] * len(subphase_names)
+
     for i, subphase in enumerate(subphase_names):
         start, end = subphase_times[i]
         color = bg_colors[i]
@@ -358,7 +376,7 @@ def _hr_ensemble_plot_subphase_vspans(
     ax.set_xticks([start for (start, end) in subphase_times])
 
 
-def hr_mean_plot(
+def hr_mean_plot(  # pylint:disable=too-many-branches
     data: MeanSeDataFrame,
     **kwargs,
 ) -> Tuple[plt.Figure, plt.Axes]:
@@ -380,10 +398,12 @@ def hr_mean_plot(
         additional parameters to be passed to the plot, such as:
 
         * ``ax``: pre-existing axes for the plot. Otherwise, a new figure and axes object is created and returned.
-        * ``colormap``: colormap to plot data from different phases
         * ``figsize``: tuple specifying figure dimensions
+        * ``palette``: color palette to plot data from different conditions. If ``palette`` is a str then it is
+          assumed to be the name of a BioPsyKit palette (:const:`biopsykit.colors.FAU_COLORS`).
         * ``is_relative``: boolean indicating whether heart rate data is relative (in % relative to baseline)
           or absolute (in bpm). Default: ``False``
+        * ``order``: list specifying the order of categorical values (i.e., conditions) along the x axis.
         * ``x_offset``: offset value to move different groups along the x axis for better visualization.
           Default: 0.05
         * ``xlabel``: label of x axis. Default: "Subphases" (if subphases are present)
@@ -413,11 +433,16 @@ def hr_mean_plot(
 
     """
     fig, ax = _plot_get_fig_ax(**kwargs)
-
     kwargs.update({"ax": ax})
 
+    num_conditions = 1
+    if "condition" in data.index.names:
+        num_conditions = len(data.index.names)
+
     # get all plot parameter
-    sns.set_palette(kwargs.get("colormap", _hr_mean_plot_params.get("colormap")))
+    palette = kwargs.get("palette")
+    palette = _get_palette(palette, num_conditions)
+    sns.set_palette(palette)
 
     ylabel_default = _hr_mean_plot_params.get("ylabel")
     if kwargs.get("is_relative", False):
@@ -436,7 +461,11 @@ def hr_mean_plot(
     x_lims = x_lims - 0.5 * np.ediff1d(x_lims, to_end=dist)
 
     if "condition" in data.index.names:
-        for i, (key, df) in enumerate(data.groupby("condition")):
+        data_grp = {key: df for key, df in data.groupby("condition")}  # pylint:disable=unnecessary-comprehension
+        order = kwargs.get("order", list(data_grp.keys()))
+        data_grp = {key: data_grp[key] for key in order}
+
+        for i, (key, df) in enumerate(data_grp.items()):
             _hr_mean_plot(df, x_vals, key, index=i, **kwargs)
     else:
         _hr_mean_plot(data, x_vals, "Data", index=0, **kwargs)
@@ -564,21 +593,25 @@ def _hr_mean_plot_subphase_annotations(phase_dict: Dict[str, Sequence[str]], xli
 
     """
     ax: plt.Axes = kwargs.get("ax")
-    bg_colors = kwargs.get("background_color", _hr_mean_plot_params.get("background_color"))
-    bg_alpha = kwargs.get("background_alpha", _hr_mean_plot_params.get("background_alpha"))
-    phase_text = kwargs.get("phase_text", _hr_mean_plot_params.get("phase_text"))
 
     num_phases = len(phase_dict)
     num_subphases = [len(arr) for arr in phase_dict.values()]
 
-    if num_phases > len(bg_colors):
-        # repeat the background colors if there are more phases than available colors
-        bg_colors = bg_colors * ((num_phases // len(bg_colors)) + 1)
+    bg_colors = kwargs.get("background_color", _hr_ensemble_plot_params.get("background_color"))
+    if bg_colors is None:
+        bg_color_base = kwargs.get("background_base_color", _hr_ensemble_plot_params.get("background_base_color"))
+        bg_colors = list(sns.dark_palette(bg_color_base, n_colors=num_phases, reverse=True))
+    bg_alphas = kwargs.get("background_alpha", _hr_ensemble_plot_params.get("background_alpha"))
+    bg_alphas = [bg_alphas] * num_phases
+
+    phase_text = kwargs.get("phase_text", _hr_mean_plot_params.get("phase_text"))
 
     x_spans = _hr_mean_get_x_spans(num_phases, num_subphases)
 
-    for (i, phase), bg_color in zip(enumerate(phase_dict), bg_colors):
+    for (i, phase) in enumerate(phase_dict):
         left, right = x_spans[i]
+        bg_color = bg_colors[i]
+        bg_alpha = bg_alphas[i]
         ax.axvspan(xlims[left], xlims[right], color=bg_color, alpha=bg_alpha, zorder=0, lw=0)
         name = phase_text.format(phase)
         ax.text(
@@ -633,7 +666,7 @@ def _hr_mean_get_phases_subphases(data: pd.DataFrame) -> Dict[str, Sequence[str]
     return phase_dict
 
 
-def saliva_plot(
+def saliva_plot(  # pylint:disable=too-many-branches
     data: Union[
         SalivaRawDataFrame, SalivaMeanSeDataFrame, Dict[str, SalivaRawDataFrame], Dict[str, SalivaMeanSeDataFrame]
     ],
@@ -641,6 +674,7 @@ def saliva_plot(
     sample_times: Optional[Union[Sequence[int], Dict[str, Sequence[int]]]] = None,
     test_times: Optional[Sequence[int]] = None,
     sample_times_absolute: Optional[bool] = False,
+    remove_s0: Optional[bool] = False,
     **kwargs,
 ) -> Optional[Tuple[plt.Figure, plt.Axes]]:
     r"""Plot saliva data during psychological protocol as mean ± standard error.
@@ -677,13 +711,15 @@ def saliva_plot(
         ``True`` if absolute sample times were provided (i.e., the duration of the psychological test was already
         added to the sample times), ``False`` if relative sample times were provided and absolute times should be
         computed based on test times specified by ``test_times``. Default: ``False``
+    remove_s0 : bool, optional
+        whether to remove the first saliva sample for plotting or not. Default: ``False``
     **kwargs
         additional parameters to be passed to the plot.
 
         To style general plot appearance:
 
         * ``ax``: pre-existing axes for the plot. Otherwise, a new figure and axes object is created and returned.
-        * ``colormap``: colormap to plot data from different phases
+        * ``palette``: color palette to plot data from different phases
         * ``figsize``: tuple specifying figure dimensions
         * ``marker``: string or list of strings to specify marker style.
           If ``marker`` is a string, then the markers of each line will have the same style.
@@ -706,6 +742,7 @@ def saliva_plot(
         To style the vertical span highlighting the psychological test in the plot:
 
         * ``test_title``: title of test
+        * ``test_fontsize``: fontsize of the test title. Default: "medium"
         * ``test_color``: color of vspan. Default: #9e9e9e
         * ``test_alpha``: transparency value of vspan: Default: 0.5
 
@@ -735,20 +772,44 @@ def saliva_plot(
 
     linestyle = kwargs.pop("linestyle", None)
     marker = kwargs.pop("marker", "o")
-    colormap = kwargs.pop("colormap", None)
+    palette = kwargs.pop("palette", None)
+    if isinstance(palette, str) and palette in get_args(colors.FAU_COLORS):
+        palette = colors.fau_palette_by_name(palette)(len(data))
 
     for i, key in enumerate(data):
-        kwargs_copy = _saliva_plot_extract_style_params(key, linestyle, marker, colormap, **kwargs)
+        df = data[key]
+        st = sample_times[key]
+        if remove_s0:
+            df = _remove_s0(df)
+            st = st[1:]
+        kwargs_copy = _saliva_plot_extract_style_params(key, linestyle, marker, palette, **kwargs)
         _saliva_plot(
-            data=data[key],
+            data=df,
             saliva_type=key,
             counter=i,
-            sample_times=sample_times[key],
+            sample_times=st,
             test_times=test_times,
             sample_times_absolute=sample_times_absolute,
             **kwargs_copy,
         )
 
+    test_times = test_times or [0, 0]
+    test_title = kwargs.get("test_title", _saliva_plot_params.get("test_title"))
+    test_color = kwargs.get("test_color", _saliva_plot_params.get("test_color"))
+    test_alpha = kwargs.get("test_alpha", _saliva_plot_params.get("test_alpha"))
+    test_fontsize = kwargs.get("test_fontsize", _saliva_plot_params.get("test_fontsize"))
+    if sum(test_times) != 0:
+        ax.axvspan(*test_times, color=test_color, alpha=test_alpha, zorder=1, lw=0)
+        ax.text(
+            x=test_times[0] + 0.5 * (test_times[1] - test_times[0]),
+            y=0.95,
+            transform=ax.get_xaxis_transform(),
+            s=test_title,
+            fontsize=test_fontsize,
+            horizontalalignment="center",
+            verticalalignment="top",
+        )
+
     if len(data) > 1:
         saliva_plot_combine_legend(fig, saliva_types=list(data.keys()), **kwargs)
     else:
@@ -761,7 +822,7 @@ def _saliva_plot_extract_style_params(
     key: str,
     linestyle: Union[Dict[str, str], str],
     marker: Union[Dict[str, str], str],
-    colormap: Union[Dict[str, str], str],
+    palette: Union[Dict[str, str], str],
     **kwargs,
 ):
     ls = _saliva_plot_get_plot_param(linestyle, key)
@@ -772,9 +833,9 @@ def _saliva_plot_extract_style_params(
     if marker is not None:
         kwargs.setdefault("marker", m)
 
-    cmap = _saliva_plot_get_plot_param(colormap, key)
-    if colormap is not None:
-        kwargs.setdefault("colormap", cmap)
+    cmap = _saliva_plot_get_plot_param(palette, key)
+    if palette is not None:
+        kwargs.setdefault("palette", cmap)
 
     return kwargs
 
@@ -810,9 +871,6 @@ def _saliva_plot(
     ax: plt.Axes = kwargs.get("ax")
 
     test_times = test_times or [0, 0]
-    test_title = kwargs.get("test_title", _saliva_plot_params.get("test_title"))
-    test_color = kwargs.get("test_color", _saliva_plot_params.get("test_color"))
-    test_alpha = kwargs.get("test_alpha", _saliva_plot_params.get("test_alpha"))
     xlabel = kwargs.get("xlabel", _saliva_plot_params.get("xlabel"))
     ylabel = kwargs.get("ylabel", _saliva_plot_params.get("ylabel"))
     xticks = kwargs.get("xticks")
@@ -838,20 +896,9 @@ def _saliva_plot(
     kwargs.setdefault("marker", "o")
 
     if counter == 0 and len(ax.lines) == 0:
-        kwargs.setdefault("colormap", colors.fau_palette_blue("line_2"))
-        if sum(test_times) != 0:
-            ax.axvspan(*test_times, color=test_color, alpha=test_alpha, zorder=1, lw=0)
-            ax.text(
-                x=test_times[0] + 0.5 * (test_times[1] - test_times[0]),
-                y=0.95,
-                transform=ax.get_xaxis_transform(),
-                s=test_title,
-                fontsize="small",
-                horizontalalignment="center",
-                verticalalignment="top",
-            )
+        kwargs.setdefault("palette", colors.fau_palette_blue(2))
     else:
-        kwargs.setdefault("colormap", colors.fau_palette_tech("line_2"))
+        kwargs.setdefault("palette", colors.fau_palette_tech(2))
         # the was already something drawn into the axis => we are using the same axis to add another feature
         ax_twin = ax.twinx()
         kwargs.update({"ax": ax_twin, "show_legend": False})
