@@ -6,6 +6,7 @@ from biopsykit.questionnaires.questionnaires import (
     asku,
     asi,
     asq,
+    asq_mod,
     bfi_k,
     bfi_10,
     bidr,
@@ -21,6 +22,9 @@ from biopsykit.questionnaires.questionnaires import (
     fscrs,
     ghq,
     hads,
+    idq_pre_scan,
+    idq_post_scan,
+    ie_4,
     kkg,
     lsq,
     meq,
@@ -39,6 +43,7 @@ from biopsykit.questionnaires.questionnaires import (
     pss,
     psqi,
     purpose_life,
+    resilience,
     rmidi,
     rsq,
     rse,
@@ -55,12 +60,14 @@ from biopsykit.questionnaires.questionnaires import (
     svf_120,
     state_rumination,
     swls,
+    tb,
     tics_l,
     tics_s,
     tsgs,
     trait_rumination,
     type_d,
     kab,
+    wpi,
 )
 from biopsykit.questionnaires import utils
 
@@ -71,6 +78,7 @@ __all__ = [
     "asi",
     "asku",
     "asq",
+    "asq_mod",
     "bfi_k",
     "bfi_10",
     "bidr",
@@ -87,6 +95,9 @@ __all__ = [
     "fscrs",
     "ghq",
     "hads",
+    "idq_pre_scan",
+    "idq_post_scan",
+    "ie_4",
     "kab",
     "kkg",
     "lsq",
@@ -106,6 +117,7 @@ __all__ = [
     "psqi",
     "pss",
     "purpose_life",
+    "resilience",
     "rmidi",
     "rse",
     "rsq",
@@ -122,10 +134,12 @@ __all__ = [
     "svf_42",
     "svf_120",
     "swls",
+    "tb",
     "tics_l",
     "tics_s",
     "trait_rumination",
     "tsgs",
     "type_d",
     "utils",
+    "wpi",
 ]
