@@ -2,10 +2,11 @@
 import warnings
 import re
 
-from typing import Optional, Union, Sequence, Tuple, Dict, Literal, Any
-
+from typing import Optional, Union, Sequence, Tuple, Dict, Any
 from inspect import getmembers, isfunction
 
+from typing_extensions import Literal
+
 import numpy as np
 import pandas as pd
 
