@@ -1,5 +1,5 @@
 """Module for ECG data analysis and visualization."""
 from biopsykit.signals.ecg.ecg import EcgProcessor
-import biopsykit.signals.ecg.plotting as plotting
+from biopsykit.signals.ecg import plotting
 
 __all__ = ["EcgProcessor", "plotting"]
