@@ -1,7 +1,7 @@
 """Module to perform sleep/wake detection based on Actigraphy or IMU data."""
 
 from biopsykit.sleep.sleep_wake_detection.sleep_wake_detection import SleepWakeDetection
-import biopsykit.sleep.sleep_wake_detection.algorithms as algorithms
+from biopsykit.sleep.sleep_wake_detection import algorithms
 
 __all__ = [
     "algorithms",
